/** Add a counter before subsections **/
h1 {
    counter-reset: subsection;
}
h2 {
    counter-reset: subsubsection;
}
h2::before {
    counter-increment: subsection;
    content: counter(subsection) ". ";
}
h3::before {
    counter-increment: subsubsection;
    content: counter(subsection) "." counter(subsubsection) ". ";
}
